.. Flask-AWSCognito documentation master file, created by
   sphinx-quickstart on Fri Sep 20 15:29:40 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Flask-AWSCognito's documentation!
============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   configure_aws
   configure_flask
   auth_code


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
